module MetaRPC
  # RPC possible errors
  class RPCError < StandardError
    attr_reader :code, :forced_code

    CODE_TO_MESSAGE = {
      parse_error: {
        code: -32_700,
        message: 'Invalid JSON was received by the server.'
      },
      invalid_request: {
        code: -32_600,
        message: 'The JSON sent is not a valid Request object.'
      },
      method_not_found: {
        code: -32_601,
        message: 'The method does not exist / is not available.'
      },
      invalid_params: {
        code: -32_602,
        message: 'Invalid method parameter(s).'
      },
      internal_error: {
        code: -32_603,
        message: 'Internal JSON-RPC error.'
      },
      server_error: {
        code: -32_000,
        message: 'Server error occurred.'
      }
    }.freeze

    def initialize(code)
      if code.is_a?(Symbol)
        @code = code
      else
        @forced_code = code
      end
    end

    def to_h
      forced_code || CODE_TO_MESSAGE[code]
    end
  end
end
